/*
 * Copyright ©Rastislav Mirek. All rights reserved.
 * No waranty for this software or derived works.
 */

package cz.muni.fi.pb162.contactsexample.catalog;

import java.util.Collection;
import java.util.SortedSet;

/**
 * This interface represents ContactsCatalog.
 *
 * Created 10.12.2009 at 12:48:59.
 *
 * @author Rastislav Mirek <rmirek at mail.muni.cz>
 * @version %I%, %G%
 * @since 1.0
 */
public interface ContactsCatalog {

    SortedSet<Person> getAllPersonsAccordingToSurname();

    SortedSet<Person> getAllPersonsAccordingToFirstName();

    /**
     * @param person Person whose numbers are to return
     * @return Collection of all numbers of given person. Collection returns
     * numbers in order according to type of Number. No duplicities are allowed
     * in returned collection
     */
    Collection<PhoneNumber> getNumbersForOfPersonAccordingToType(Person person);

    /**
     * @param person Person whose numbers are to return
     * @return Collection of all numbers of given person. Collection returns 
     * numbers in order according to number of Number. No duplicities are allowed
     * in returned collection
     */
    Collection<PhoneNumber> getNumbersForOfPersonAccordingToNumber(Person person);

    void addPerson(Person newPerson);

    /**
     * @param forPerson Person to add number to.
     * @param newNumber Number to add. May not be already contained in Calatog. If it is
     * IllegalArgumentException will be thrown.
     */
    void addNumber(Person forPerson, PhoneNumber newNumber);

    /**
     * Deletes person and all its numbers
     * @param person
     */
    void deletePerson(Person person);

    void deleteNumber(PhoneNumber number);

    Person getPersonForNumber(PhoneNumber number);

    boolean containsNumber(PhoneNumber number);

    boolean contactnsPerson(Person person);

    void save(String filePath);

    void load(String filePath);
}
